from pydantic import BaseModel

class ProjectRolesController_search(BaseModel):
    '''
    Получить список
    
    token:str - Токен (Обязательно)
    projectId:str - ID проекта (Обязательно)
    limit:int - Количество элементов, которые хочется получить. Максимум 1000 (По умолчанию = 50)
    name:str - Имя роли (Необязательно)
    offset:int - Индекс первого элемента страницы  (По умолчанию = 0)
    
    https://ru.yougile.com/api-v2#/operations/ProjectRolesController_search
    '''
    _method:str = 'get'
    _url:str = '/api-v2/projects/{projectId}/roles'
    token:str
    _url_parse:tuple = ('projectId',)
    _url_params:tuple = ('limit','name','offset')
    projectId:str
    limit:int=50
    name:str|None = None
    offset:int=0
    
class ProjectRolesController_create(BaseModel):
    '''
    Создать
    
    token:str - Токен (Обязательно)
    projectId:str - ID проекта (Обязательно)
    name:str - Название роли (Обязательно)
    description:str - Описание роли (Необязательно)
    permissions:dict - Права в проекте (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/ProjectRolesController_create
    '''
    _method:str = 'post'
    _url:str = '/api-v2/projects/{projectId}/roles'
    token:str
    _url_parse:tuple = ('projectId',)
    projectId:str
    name:str
    description:str|None = None
    permissions:dict
    
class ProjectRolesController_get(BaseModel):
    '''
    Получить по ID

    token:str - Токен (Обязательно)
    id:str - ID роли проекта (Обязательно)
    projectId:str - ID проекта (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/ProjectRolesController_get
    '''
    _method:str = 'get'
    _url:str = '/api-v2/projects/{projectId}/roles/{id}'
    token:str
    _url_parse:tuple = ('projectId','id')
    id:str
    projectId:str
    
class ProjectRolesController_update(BaseModel):
    '''
    Изменить
    
    token:str - Токен (Обязательно)
    id:str - ID проекта (Обязательно)
    projectId:str - ID проекта (Обязательно)
    name:str - Название роли (Необязательно)
    description:str - Описание роли (Необязательно)
    permissions:dict - Права в проекте (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/ProjectRolesController_update
    '''
    _method:str = 'put'
    _url:str = '/api-v2/projects/{projectId}/roles/{id}'
    token:str
    _url_parse:tuple = ('projectId','id')
    id:str
    projectId:str
    name:str|None = None
    description:str|None = None
    permissions:dict

class ProjectRolesController_delete(BaseModel):
    '''
    Удалить
    
    token:str - Токен (Обязательно)
    id:str - ID роли проекта (Обязательно)
    projectId:str - ID проекта (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/ProjectRolesController_delete
    '''
    _method:str = 'delete'
    _url:str = '/api-v2/projects/{projectId}/roles/{id}'
    token:str
    _url_parse:tuple = ('projectId','id')
    id:str
    projectId:str


from pydantic import BaseModel

class DepartmentController_search(BaseModel):
    '''
    Получить список
    
    token:str - Токен (Обязательно)
    includeDeleted:bool - По умолчанию, если объект был отмечен как удаленный, то он не будет найден. Поставьте true, чтобы удаленные объекты возвращались (Небязательно)
    limit:int - Количество элементов, которые хочется получить. Максимум 1000 (По умолчанию = 50)
    offset:int - Индекс первого элемента страницы (По умолчанию = 0)
    parentId:str - ID родительского отдела (Небязательно)
    title:str - Имя отдела (Небязательно)
    
    https://ru.yougile.com/api-v2#/operations/DepartmentController_search
    '''
    _method:str = 'get'
    _url:str = '/api-v2/departments'
    token:str
    _url_params:tuple = ('includeDeleted','limit','offset','title')
    includeDeleted:bool|None = None
    limit:int=50
    offset:int=0
    parentId:str|None = None
    title:str|None = None
    
class DepartmentController_create(BaseModel):
    '''
    Создать
    
    token:str - Токен (Обязательно)
    title:str - Название отдела (Небязательно)
    parentId:str - Id родительского отдела. Оставить пустым или "-", если это отдел верхнего уровня (Небязательно)
    users:dict - Сотрудники на отделе и их роль. Возможные значения: 1) manager или member 2) "-" или "" для удаления существующего пользователя из отдела (Небязательно)
    
    https://ru.yougile.com/api-v2#/operations/DepartmentController_create
    '''
    _method:str = 'post'
    _url:str = '/api-v2/departments'
    token:str
    title:str|None = None
    parentId:str|None = None
    users:dict|None = None
    
class DepartmentController_get(BaseModel):
    '''
    Получить по ID
    
    token:str - Токен (Обязательно)
    id:str - ID отдела (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/DepartmentController_get
    '''
    _method:str = 'get'
    _url:str = '/api-v2/departments/{id}'
    token:str
    _url_parse:tuple = ('id',)
    id:str
    
class DepartmentController_update(BaseModel):
    '''
    Изменить
    
    token:str - Токен (Обязательно)
    id:str - ID отдела (Обязательно)
    deleted:bool - Если true, значит объект удален (Небязательно)
    title:str - Название отдела (Небязательно)
    parentId:str - Id родительского отдела. Оставить пустым или "-", если это отдел верхнего уровня (Небязательно)
    users:dict - Сотрудники на отделе и их роль. Возможные значения: 1) manager или member 2) "-" или "" для удаления существующего пользователя из отдела (Небязательно)
    
    https://ru.yougile.com/api-v2#/operations/DepartmentController_update
    '''
    _method:str = 'put'
    _url:str = '/api-v2/departments/{id}'
    token:str
    _url_parse:tuple = ('id',)
    id:str
    deleted:bool|None = None
    title:str|None = None
    parentId:str|None = None
    users:dict|None = None


from pydantic import BaseModel
class AuthKeyController_companiesList(BaseModel):
    '''
    Получить список компаний
    
    login:str - Логин пользователя (Обязательно)
    password:str - Пароль пользователя (Обязательно)
    name:str - Название компании (Необязательно)
    
    limit:int - Количество элементов, которые хочется получить. Максимум 1000 (По умолчанию = 50)
    offset:int - Индекс первого элемента страницы (По умолчанию = 0)
    
    https://ru.yougile.com/api-v2#/operations/AuthKeyController_companiesList
    '''
    _method:str = 'post'
    _url:str = '/api-v2/auth/companies'
    _url_params:tuple = ('limit','offset')
    login:str
    password:str
    name:str|None = None
    
    limit:int=50
    offset:int=0
    
    
class AuthKeyController_search(BaseModel):
    '''
    Получить список ключей
    
    login:str - Логин пользователя (Обязательно)
    password:str - Пароль пользователя (Обязательно)
    companyId:str - ID компании (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/AuthKeyController_search
    '''
    _method:str = 'post'
    _url:str = '/api-v2/auth/keys/get'
    login:str
    password:str
    companyId:str
    
class AuthKeyController_create(BaseModel):
    '''
    Создать ключ
    
    login:str - Логин пользователя (Обязательно)
    password:str - Пароль пользователя (Обязательно)
    companyId:str - ID компании (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/AuthKeyController_create
    '''
    _method:str = 'post'
    _url:str = '/api-v2/auth/keys'
    login:str
    password:str
    companyId:str
    
class AuthKeyController_delete(BaseModel):
    '''
    Удалить ключ
    
    key:str - Ключ (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/AuthKeyController_delete
    '''
    _method:str = 'delete'
    _url:str = '/api-v2/auth/keys/{key}'
    _url_parse:tuple = ('key',)
    key:str


from .auth import *
from .boards import *
from .chatmessages import *
from .columns import *
from .departments import *
from .employees import *
from .groupchats import *
from .projectroles import *
from .projects import *
from .sprintsticker import *
from .sprintstickerstate import *
from .stringsticker import *
from .stringstickerstate import *
from .tasks import *
from .webhooks import *


from pydantic import BaseModel

class TaskController_search(BaseModel):
    '''
    Получить список
    
    token:str - Токен (Обязательно)
    columnId:str - ID колонки (Необязательно)
    includeDeleted:bool - По умолчанию, если объект был отмечен как удаленный, то он не будет найден. Поставьте true, чтобы удаленные объекты возвращались (Необязательно)
    limit:int - Количество элементов, которые хочется получить. Максимум 1000 (По умолчанию = 50)
    offset:int - Индекс первого элемента страницы (По умолчанию = 0)
    title:str - Заголовок задачи (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/TaskController_search
    '''
    _method:str = 'get'
    _url:str = '/api-v2/tasks'
    token:str
    _url_params:tuple = ('columnId','includeDeleted','limit','offset','title')
    columnId:str|None = None
    includeDeleted:bool|None = None
    limit:int=50
    offset:int=0
    title:str|None = None
    
class TaskController_create(BaseModel):
    '''
    Создать
    
    token:str - Токен (Обязательно)
    title:str - Название задачи (Обязательно)
    columnId:str - ID колонки родителя (Необязательно)
    description:str - Описание задачи (Необязательно)
    archived:bool - Задача перенесена в архив - True|False (Необязательно)
    completed:bool - Задача выполнена - True|False (Необязательно)
    subtasks:list - Массив ID подзадач (Необязательно)
    assigned:list - Массив ID пользователей, на которых назначена задача (Необязательно)
    deadline:dict - Стикер "Дэдлайн". Указывает на крайний срок выполнения задачи. Имеется возможность кроме даты указать время, а так же дату начала задачи (Необязательно)
    timeTracking:dict - Стикер "Таймтрекинг". Используется для указания ожидаемого и реального времени на выполнение задачи (Необязательно)
    checklists:list - Чеклисты. К задаче всегда будет присвоен переданный объект. Если необходимо внести изменения, нужно сначала получить чеклисты, затем произвести корректировку, а затем записать в задачу заново (Необязательно)
    stickers:dict - Пользовательские стикеры. Передаются в виде объекта ключ-значение. Где ключ - это ID стикера, значение - ID состояния. Для открепления стикера от задачи, используйте "-" как значение состояния (Необязательно)
    stopwatch:dict - Стикер "Секундомер". Позволяет запустить секундомер, а так же ставить его на паузу и запускать заново (Необязательно)
    timer:dict - Стикер "Таймер". Позволяет установить таймер на заданное время, а также возможность ставить его на паузу и запускать заново (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/TaskController_create
    '''
    _method:str = 'post'
    _url:str = '/api-v2/tasks'
    token:str
    title:str
    columnId:str|None = None
    description:str|None = None
    archived:bool|None = None
    completed:bool|None = None
    subtasks:list|None = None
    assigned:list|None = None
    deadline:dict|None = None
    timeTracking:dict|None = None
    checklists:list|None = None
    stickers:dict|None = None
    stopwatch:dict|None = None
    timer:dict|None = None

class TaskController_get(BaseModel):
    '''
    Получить по ID
    
    token:str - Токен (Обязательно)
    id:str - ID задачи (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/BoardController_get
    '''
    _method:str = 'get'
    _url:str = '/api-v2/tasks/{id}'
    _url_parse:tuple = ('id',)
    id:str
    
class TaskController_update(BaseModel):
    '''
    Изменить
    
    token:str - Токен (Обязательно)
    id:str - ID задачи (Обязательно)
    deleted:bool - Если true, значит объект удален (Необязательно)
    title:str - Название задачи (Необязательно)
    columnId:str - ID колонки родителя (Необязательно)
    description:str - Описание задачи (Необязательно)
    archived:bool - Задача перенесена в архив - True|False (Необязательно)
    completed:bool - Задача выполнена - True|False (Необязательно)
    subtasks:list - Массив ID подзадач (Необязательно)
    assigned:list - Массив ID пользователей, на которых назначена задача (Необязательно)
    deadline:dict - Стикер "Дэдлайн". Указывает на крайний срок выполнения задачи. Имеется возможность кроме даты указать время, а так же дату начала задачи (Необязательно)
    timeTracking:dict - Стикер "Таймтрекинг". Используется для указания ожидаемого и реального времени на выполнение задачи (Необязательно)
    checklists:list - Чеклисты. К задаче всегда будет присвоен переданный объект. Если необходимо внести изменения, нужно сначала получить чеклисты, затем произвести корректировку, а затем записать в задачу заново (Необязательно)
    stickers:dict - Пользовательские стикеры. Передаются в виде объекта ключ-значение. Где ключ - это ID стикера, значение - ID состояния. Для открепления стикера от задачи, используйте "-" как значение состояния (Необязательно)
    stopwatch:dict - Стикер "Секундомер". Позволяет запустить секундомер, а так же ставить его на паузу и запускать заново (Необязательно)
    timer:dict - Стикер "Таймер". Позволяет установить таймер на заданное время, а также возможность ставить его на паузу и запускать заново (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/BoardController_update
    '''
    _method:str = 'put'
    _url:str = '/api-v2/tasks/{id}'
    _url_parse:tuple = ('id',)
    id:str
    deleted:bool|None = None
    title:str|None = None
    columnId:str|None = None
    description:str|None = None
    archived:bool|None = None
    completed:bool|None = None
    subtasks:list|None = None
    assigned:list|None = None
    deadline:dict|None = None
    timeTracking:dict|None = None
    checklists:list|None = None
    stickers:dict|None = None
    stopwatch:dict|None = None
    timer:dict|None = None


from pydantic import BaseModel

class ChatMessageController_search(BaseModel):
    '''
    Получить историю сообщений
    
    token:str - Токен (Обязательно)
    chatId:str - ID чата (Обязательно)
    fromUserId:str - ID сотрудника от кого сообщение (Необязательно)
    includeDeleted:bool - По умолчанию, если объект был отмечен как удаленный, то он не будет найден. Поставьте true, чтобы удаленные объекты возвращались (Необязательно)
    includeSystem:bool - Включать ли системные сообщения. По умолчанию они не включаются (Необязательно)
    label:str - Поиск по быстрой ссылке сообщения (Необязательно)
    limit:int - Количество элементов, которые хочется получить. Максимум 1000 (Необязательно)
    offset:int - Индекс первого элемента страницы (Необязательно)
    since:int - Искать среди сообщений, время создания которых позже указанного времени (timestamp) (Необязательно)
    text:str - Строка, которую сообщение должно содержать (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/ChatMessageController_search
    '''
    _method:str = 'get'
    _url:str = '/api-v2/chats/{chatId}/messages'
    token:str
    _url_parse:tuple = ('chatId',)
    _url_params:tuple = ('fromUserId','includeDeleted','includeSystem','label','limit','offset','since','text')
    chatId:str
    fromUserId:str|None = None
    includeDeleted:bool|None = None
    includeSystem:bool|None = None
    label:str|None = None
    limit:int=50
    offset:int=0
    since:int|None = None
    text:str|None = None
    
class ChatMessageController_sendMessage(BaseModel):
    '''
    Написать в чат
    
    token:str - Токен (Обязательно)
    chatId:str - ID чата (Обязательно)
    text:str - Текст сообщения (Обязательно)
    textHtml:int - Текст сообщения в формате HTML (Обязательно)
    label:str - Быстрая ссылка (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/ChatMessageController_sendMessage
    '''
    _method:str = 'post'
    _url:str = '/api-v2/chats/{chatId}/messages'
    token:str
    _url_parse:tuple = ('chatId',)
    chatId:str
    text:str
    textHtml:int
    label:str
    
class ChatMessageController_get(BaseModel):
    '''
    Получить сообщение по ID
    
    token:str - Токен (Обязательно)
    chatId:str - ID чата (Обязательно)
    id:str ID сообщения (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/ChatMessageController_get
    '''
    _method:str = 'get'
    _url:str = '/api-v2/chats/{chatId}/messages/{id}'
    token:str
    _url_parse:tuple = ('chatId','id')
    chatId:str
    id:str
    
class ChatMessageController_update(BaseModel):
    '''
    Изменить сообщение
    
    token:str - Токен (Обязательно)
    chatId:str - ID чата (Обязательно)
    id:str - ID сообщения (Обязательно)
    deleted:bool - Если true, значит объект удален (Необязательно)
    label:str - Быстрая ссылка (Необязательно)
    react:str - Список реакций админа. Допустимые значения: 👍 👎 👏 🙂 😀 😕 🎉 ❤ 🚀 ✔ (По умолчанию = 👍)

    https://ru.yougile.com/api-v2#/operations/ChatMessageController_update
    '''
    _method:str = 'put'
    _url:str = '/api-v2/chats/{chatId}/messages/{id}'
    token:str
    _url_parse:tuple = ('chatId','id')
    chatId:str
    id:str
    deleted:bool|None = None
    label:str|None = None
    react:str = '👍'


from pydantic import BaseModel

class SprintStickerController_search(BaseModel):
    '''
    Получить список
    
    token:str - Токен (Обязательно)
    boardId:str - ID доски (Необязательно)
    includeDeleted:bool - По умолчанию, если объект был отмечен как удаленный, то он не будет найден. Поставьте true, чтобы удаленные объекты возвращались (Необязательно)
    limit:int - Количество элементов, которые хочется получить. Максимум 1000 (По умолчанию = 50)
    name:str - Имя стикера (Необязательно)
    offset:int - Индекс первого элемента страницы (По умолчанию = 0)
    
    https://ru.yougile.com/api-v2#/operations/SprintStickerController_search
    '''
    _method:str = 'get'
    _url:str = '/api-v2/sprint-stickers'
    token:str
    _url_params:tuple = ('boardId','includeDeleted','limit','name','offset')
    boardId:str|None = None
    includeDeleted:bool|None = None
    limit:int=50
    name:str|None = None
    offset:int=0
    
class SprintStickerController_create(BaseModel):
    '''
    Создать
    
    token:str - Токен (Обязательно)
    name:str - Имя стикера (Обязательно)
    states:list (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/SprintStickerController_create
    '''
    _method:str = 'post'
    _url:str = '/api-v2/sprint-stickers'
    token:str
    name:str
    states:list
    
class SprintStickerController_getSticker(BaseModel):
    '''
    Получить по ID
    
    token:str - Токен (Обязательно)
    id:str - ID стикера спринта (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/SprintStickerController_getSticker
    '''
    _method:str = 'get'
    _url:str = '/api-v2/sprint-stickers/{id}'
    token:str
    _url_parse:tuple = ('id',)
    id:str
    
class SprintStickerController_update(BaseModel):
    '''
    Изменить
    
    token:str - Токен (Обязательно)
    id:str - ID стикера спринта (Обязательно)
    deleted:bool - Если true, значит объект удален (Необязательно)
    name:str (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/SprintStickerController_update
    '''
    _method:str = 'put'
    _url:str = '/api-v2/sprint-stickers/{id}'
    token:str
    _url_parse:tuple = ('id',)
    id:str
    deleted:bool|None = None
    name:str|None = None


from pydantic import BaseModel

class BoardController_search(BaseModel):
    '''
    Получить список
    
    token:str - Токен (Обязательно)
    includeDeleted:bool - По умолчанию, если объект был отмечен как удаленный, то он не будет найден. Поставьте true, чтобы удаленные объекты возвращались (Необязательно)
    limit:int - Количество элементов, которые хочется получить. Максимум 1000 (По умолчанию = 50)
    offset:int - Индекс первого элемента страницы (По умолчанию = 0)
    projectId:str - ID проекта (Необязательно)
    title:str - Имя доски (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/BoardController_search
    '''
    _method:str = 'get'
    _url:str = '/api-v2/boards'
    token:str
    _url_params:tuple = ('includeDeleted','limit','offset','projectId','title')
    includeDeleted:bool|None = None
    limit:int=50
    offset:int=0
    projectId:str|None = None
    title:str|None = None
    
class BoardController_create(BaseModel):
    '''
    Создать
    
    token:str - Токен (Обязательно)
    title:str - Название доски (Обязательно)
    projectId:str - Id проекта, в котором находится доска (Обязательно)
    stickers:dict - Стикеры доски (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/BoardController_create
    '''
    _method:str = 'post'
    _url:str = '/api-v2/boards'
    token:str
    title:str
    projectId:str
    stickers:dict

class BoardController_get(BaseModel):
    '''
    Получить по ID
    
    token:str - Токен (Обязательно)
    id:str - ID доски (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/BoardController_get
    '''
    _method:str = 'get'
    _url:str = '/api-v2/boards/{id}'
    token:str
    _url_parse:tuple = ('id',)
    id:str
    
class BoardController_update(BaseModel):
    '''
    Изменить
    
    token:str - Токен (Обязательно)
    id:str - ID доски (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/BoardController_update
    '''
    _method:str = 'put'
    _url:str = '/api-v2/boards/{id}'
    token:str
    _url_parse:tuple = ('id',)
    id:str
    deleted:bool
    title:str
    projectId:str
    stickers:dict


from pydantic import BaseModel
from requests import Response
import requests

YOUGILE_URL = 'https://ru.yougile.com'

def query(arg:BaseModel,token:str|None=None) -> Response:
    arg = arg.model_copy()
    url = arg._url
    headers = {}
    headers.update({'Content-Type':'application/json'})
    
    if hasattr(arg,'token'):
        if token == None:
            headers.update({'Authorization':f'Bearer {arg.token}'})
            delattr(arg,'token')
        else:
            headers.update({'Authorization':f'Bearer {token}'})
    if hasattr(arg,'_url_parse'):
        for i in arg._url_parse:
            url = url.format(**{i:getattr(arg,i)})
            delattr(arg,i)
    if hasattr(arg,'_url_params'):
        params = []
        for i in arg._url_params:
            if getattr(arg,i) != None:
                params.append(f'{i}={getattr(arg,i)}')
            delattr(arg,i)
        params = '&'.join(params)
        url += '?' + params
    body = arg.model_dump()
    bres = {}
    for i in zip(body.keys(),body.values()):
        if i[1] != None:
            bres.update({i[0]:i[1]})
    if bres != {}:
        return getattr(requests,arg._method)(url=YOUGILE_URL+url,headers=headers,json=bres)
    else:
        return getattr(requests,arg._method)(url=YOUGILE_URL+url,headers=headers)


from pydantic import BaseModel

class UserController_search(BaseModel):
    '''
    Получить список
    
    token:str - Токен (Обязательно)
    email:str - Почта сотрудника (Небязательно)
    limit:int - Количество элементов, которые хочется получить. Максимум 1000 (По умолчанию = 50)
    offset:int - Индекс первого элемента страницы  (По умолчанию = 0)
    projectId:str - ID проекта (Небязательно)
    
    https://ru.yougile.com/api-v2#/operations/UserController_search
    '''
    _method:str = 'get'
    _url:str = '/api-v2/users'
    token:str
    _url_params:tuple = ('email','limit','offset','projectId')
    email:str|None = None
    limit:int=50
    offset:int=0
    projectId:str|None = None
    
class UserController_create(BaseModel):
    '''
    Пригласить в компанию
    
    token:str - Токен (Обязательно)
    email:str - Почтовый ящик сотрудника (Обязательно)
    isAdmin:bool - Имеет ли пользователь права администратора (Небязательно)
    
    https://ru.yougile.com/api-v2#/operations/UserController_create
    '''
    _method:str = 'post'
    _url:str = '/api-v2/users'
    token:str
    email:str
    isAdmin:bool|None = None
    
class UserController_get(BaseModel):
    '''
    Получить по ID
    
    token:str - Токен (Обязательно)
    id:str - ID сотрудника (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/UserController_get
    '''
    _method:str = 'get'
    _url:str = '/api-v2/users/{id}'
    token:str
    _url_parse:tuple = ('id',)
    id:str

class UserController_update(BaseModel):
    '''
    Изменить
    
    token:str - Токен (Обязательно)
    id:str - ID сотрудника (Обязательно)
    isAdmin:bool - Имеет ли пользователь права администратора  (Небязательно)
    
    https://ru.yougile.com/api-v2#/operations/UserController_update
    '''
    _method:str = 'put'
    _url:str = '/api-v2/users/{id}'
    token:str
    _url_parse:tuple = ('id',)
    id:str
    isAdmin:bool|None = None
    
class UserController_delete(BaseModel):
    '''
    Удалить из компании
    
    token:str - Токен (Обязательно)
    id:str - ID сотрудника (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/UserController_delete
    '''
    _method:str = 'delete'
    _url:str = '/api-v2/users/{id}'
    token:str
    _url_parse:tuple = ('id',)
    id:str


from pydantic import BaseModel

class StringStickerStateController_get(BaseModel):
    '''
    Получить по ID
    
    token:str - Токен (Обязательно)
    stickerId:str - ID текстового стикера (Обязательно)
    stickerStateId:str - ID состояния текстового стикера (Обязательно)
    includeDeleted:bool - По умолчанию, если объект был отмечен как удаленный, то он не будет найден. Поставьте true, чтобы удаленные объекты возвращались (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/StringStickerStateController_get
    '''
    _method:str = 'get'
    _url:str = '/api-v2/string-stickers/{stickerId}/states/{stickerStateId}'
    _url_parse:tuple = ('stickerId','stickerStateId')
    token:str
    _url_params:tuple = ('includeDeleted',)
    stickerId:str
    stickerStateId:str
    includeDeleted:bool|None = None
    
class StringStickerStateController_update(BaseModel):
    '''
    Изменить
    
    token:str - Токен (Обязательно)
    stickerId:str - ID текстового стикера (Обязательно)
    stickerStateId:str - ID состояния текстового стикера (Обязательно)
    deleted:bool - Если true, значит объект удален (Необязательно)
    name:str - Имя состояния стикера (Необязательно)
    color:str - Цвет состояния стикера (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/StringStickerStateController_update
    '''
    _method:str = 'put'
    _url:str = '/api-v2/string-stickers/{stickerId}/states/{stickerStateId}'
    _url_parse:tuple = ('stickerId','stickerStateId')
    token:str
    stickerId:str
    stickerStateId:str
    deleted:bool|None = None
    name:str|None = None
    color:str|None = None
    
class StringStickerStateController_create(BaseModel):
    '''
    Создать
    
    token:str - Токен (Обязательно)
    stickerId:str - ID текстового стикера (Обязательно)
    name:str - Имя состояния стикера (Обязательно)
    color:str - Цвет состояния стикера (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/StringStickerStateController_create
    '''
    _method:str = 'post'
    _url:str = '/api-v2/string-stickers/{stickerId}/states'
    token:str
    _url_parse:tuple = ('stickerId',)
    stickerId:str
    name:str
    color:str|None = None


from pydantic import BaseModel

class ProjectController_search(BaseModel):
    '''
    Получить список
    
    token:str - Токен (Обязательно)
    includeDeleted:bool - По умолчанию, если объект был отмечен как удаленный, то он не будет найден. Поставьте true, чтобы удаленные объекты возвращались (Необязательно)
    limit:int - Количество элементов, которые хочется получить. Максимум 1000 (По умолчанию = 50)
    offset:int - Индекс первого элемента страницы (По умолчанию = 0)
    title:str - Имя проекта (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/ProjectController_search
    '''
    _method:str = 'get'
    _url:str = '/api-v2/projects'
    token:str
    _url_params:tuple = ('includeDeleted','limit','offset','title')
    includeDeleted:bool|None = None
    limit:int=50
    offset:int=0
    title:str|None = None
    
class ProjectController_create(BaseModel):
    '''
    Создать
    
    token:str - Токен (Обязательно)
    title:str - Название проекта (Обязательно)
    users:dict - Сотрудники на проекте и их роль. Возможные значения: 1) системные роли: worker, admin, observe 2) ID пользовательской роли 3) "-" для удаления существующего пользователя из проекта (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/ProjectController_create
    '''
    _method:str = 'post'
    _url:str = '/api-v2/projects'
    token:str
    title:str
    users:dict|None = None
    
class ProjectController_get(BaseModel):
    '''
    Получить по ID
    
    token:str - Токен (Обязательно)
    id:str - ID проекта (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/ProjectController_get
    '''
    _method:str = 'get'
    _url:str = '/api-v2/projects/{id}'
    token:str
    _url_parse:tuple = ('id',)
    id:str
    
class ProjectController_update(BaseModel):
    '''
    Изменить
    
    token:str - Токен (Обязательно)
    id:str - ID проекта (Обязательно)
    deleted:bool - Если true, значит объект удален (Необязательно)
    title:str - Название проекта (Обязательно)
    users:dict - Сотрудники на проекте и их роль. Возможные значения: 1) системные роли: worker, admin, observe 2) ID пользовательской роли 3) "-" для удаления существующего пользователя из проекта (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/ProjectController_update
    '''
    _method:str = 'put'
    _url:str = '/api-v2/projects/{id}'
    token:str
    _url_parse:tuple = ('id',)
    id:str
    deleted:bool|None = None
    title:str
    users:dict|None = None


from pydantic import BaseModel

class ColumnController_search(BaseModel):
    '''
    Получить список
    
    token:str - Токен (Обязательно)
    boardId:str - ID доски (Небязательно)
    includeDeleted:bool - По умолчанию, если объект был отмечен как удаленный, то он не будет найден. Поставьте true, чтобы удаленные объекты возвращались (Небязательно)
    limit:int - Количество элементов, которые хочется получить. Максимум 1000 (По умолчанию = 50)
    offset:int - Индекс первого элемента страницы (По умолчанию = 0)
    title:str - Имя колонки (Небязательно)
    
    https://ru.yougile.com/api-v2#/operations/ColumnController_search
    '''
    _method:str = 'get'
    _url:str = '/api-v2/columns'
    token:str
    _url_params:tuple = ('boardId','includeDeleted','limit','offset','title')
    boardId:str|None = None
    includeDeleted:bool|None = None
    limit:int=50
    offset:int=0
    title:str|None = None
    
class ColumnController_create(BaseModel):
    '''
    Создать
    
    token:str - Токен (Обязательно)
    title:str - Название колонки (Обязательно)
    color:int - Цвет колонки. Указывается в виде числа. Примеры цветов представлены ниже (Небязательно)
    boardId:str - Id доски, в которой находится колонка (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/ColumnController_create
    '''
    _method:str = 'post'
    _url:str = '/api-v2/columns'
    token:str
    title:str|None = None
    color:int|None = None
    boardId:str|None = None
    
class ColumnController_get(BaseModel):
    '''
    Получить по ID
    
    token:str - Токен (Обязательно)
    id:str - ID колонки (Обязательно)

    https://ru.yougile.com/api-v2#/operations/ColumnController_get
    '''
    _method:str = 'get'
    _url:str = '/api-v2/columns/{id}'
    token:str
    _url_parse:tuple = ('id',)
    id:str
    
class ColumnController_update(BaseModel):
    '''
    Изменить
    
    token:str - Токен (Обязательно)
    id:str - ID колонки (Обязательно)
    deleted:bool - Если true, значит объект удален (Небязательно)
    title:str - Название колонки (Небязательно)
    color:int - Цвет колонки. Указывается в виде числа. Примеры цветов представлены ниже (Небязательно)
    boardId:str - Id доски, в которой находится колонка (Небязательно)

    https://ru.yougile.com/api-v2#/operations/ColumnController_update
    '''
    _method:str = 'put'
    _url:str = '/api-v2/columns/{id}'
    token:str
    _url_parse:tuple = ('id',)
    id:str
    deleted:bool|None = None
    title:str|None = None
    color:int|None = None
    boardId:str|None = None


from pydantic import BaseModel

class SprintStickerStateController_get(BaseModel):
    '''
    Получить по ID
    
    token:str - Токен (Обязательно)
    stickerId:str - ID стикера (Обязательно)
    stickerStateId:str - ID состояния стикера (Обязательно)
    includeDeleted:bool - По умолчанию, если объект был отмечен как удаленный, то он не будет найден. Поставьте true, чтобы удаленные объекты возвращались (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/SprintStickerStateController_get
    '''
    _method:str = 'get'
    _url:str = '/api-v2/sprint-stickers/{stickerId}/states/{stickerStateId}'
    _url_parse:tuple = ('stickerId','stickerStateId')
    token:str
    _url_params:tuple = ('includeDeleted',)
    stickerId:str
    stickerStateId:str
    includeDeleted:bool|None = None
    
class SprintStickerStateController_update(BaseModel):
    '''
    Изменить
    
    token:str - Токен (Обязательно)
    stickerId:str - ID стикера (Обязательно)
    stickerStateId:str - ID состояния стикера (Обязательно)
    deleted:bool - Если true, значит объект удален (Необязательно)
    name:str - Имя состояния стикера (Необязательно)
    begin:int - Дата начала спринта в секундах от 01.01.1970 (Необязательно)
    end:int - Дата окончания спринта в секундах от 01.01.1970 (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/SprintStickerStateController_update
    '''
    _method:str = 'put'
    _url:str = '/api-v2/sprint-stickers/{stickerId}/states/{stickerStateId}'
    _url_parse:tuple = ('stickerId','stickerStateId')
    token:str
    stickerId:str
    stickerStateId:str
    deleted:bool|None = None
    name:str|None = None
    begin:int|None = None
    end:int|None = None
    
class SprintStickerStateController_create(BaseModel):
    '''
    Создать
    
    token:str - Токен (Обязательно)
    stickerId:str - ID стикера (Обязательно)
    name:str - Имя состояния стикера (Обязательно)
    begin:int - Дата начала спринта в секундах от 01.01.1970 (Необязательно)
    end:int - Дата окончания спринта в секундах от 01.01.1970 (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/SprintStickerStateController_create
    '''
    _method:str = 'post'
    _url:str = '/api-v2/sprint-stickers/{stickerId}/states'
    token:str
    _url_parse:tuple = ('stickerId',)
    stickerId:str
    name:str
    begin:int|None = None
    end:int|None = None


from pydantic import BaseModel

class WebhookController_create(BaseModel):
    '''
    Создать подписку
    
    token:str - Токен (Обязательно)
    url:str - URL подписки (Обязательно)
    event:str - Событие подписки. Формат: <тип_объекта>-<событие>. Для объектов project,board,column,task,sticker,department,group_chat,chat_message, возможные события: created,deleted,restored,moved,renamed,updated. Для объектов user, возможные события: added, removed. Может использоваться javascript regexp как значение. Например, task-* - подписка на все события по задачам, или .* - подписка на все события (Обязательно)
    
    https://ru.yougile.com/api-v2#/operations/WebhookController_create
    '''
    _method:str = 'post'
    _url:str = '/api-v2/webhooks'
    token:str
    url:str
    event:str
    
class WebhookController_search(BaseModel):
    '''
    Получить список подписок
    
    token:str - Токен (Обязательно)
    includeDeleted:bool - По умолчанию, если объект был отмечен как удаленный, то он не будет найден. Поставьте true, чтобы удаленные объекты возвращались (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/WebhookController_search
    '''
    _method:str = 'get'
    _url:str = '/api-v2/webhooks'
    token:str
    _url_params:tuple = ('includeDeleted',)
    includeDeleted:bool|None = None

class WebhookController_put(BaseModel):
    '''
    Изменить подписку
    
    token:str - Токен (Обязательно)
    id:str - ID подписки (Обязательно)
    deleted:bool - Если true, значит объект удален (Необязательно)
    url:str - URL подписки (Необязательно)
    event:str - Событие подписки. Формат: <тип_объекта>-<событие>. Для объектов project,board,column,task,sticker,department,group_chat,chat_message, возможные события: created,deleted,restored,moved,renamed,updated. Для объектов user, возможные события: added, removed. Может использоваться javascript regexp как значение. Например, task-* - подписка на все события по задачам, или .* - подписка на все события (Необязательно)
    disabled:bool - Если true, то вызываться не будет (Необязательно)
    
    https://ru.yougile.com/api-v2#/operations/WebhookController_put
    '''
    _method:str = 'put'
    _url:str = '/api-v2/webhooks/{id}'
    token:str
    _url_parse:tuple = ('id',)
    id:str
    deleted:bool|None = None
    url:str|None = None
    event:str|None = None
    disabled:bool|None = None